==> Omni-0.9.1.tar.gz: Omni/XMLDevice/XMLDeviceMedia.hpp <==
/*
 *   IBM Omni driver
 *   Copyright (c) International Business Machines Corp., 2000
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Lesser General Public License as published
 *   by the Free Software Foundation; either version 2.1 of the License, or
 *   (at your option) any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public License
 *   along with this library; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef _XMLDeviceMedia
#define _XMLDeviceMedia

#include <DeviceMedia.hpp>

#include <XMLDevice.hpp>

class XMLDeviceMedia : public DeviceMedia
{
public:
                             XMLDeviceMedia    (Device                *pDevice,
                                                PSZRO                  pszJobProperties,
                                                BinaryData            *data,
                                                int                    iColorAdjustRequired,
                                                int                    iAbsorption,
                                                xmlNodePtr             node);
   virtual                  ~XMLDeviceMedia    ();

   virtual DeviceMedia      *create            (Device                *pDevice,
                                                PSZRO                  pszJobProperties);
   static DeviceMedia       *createS           (Device                *pDevice,
                                                PSZRO                  pszJobProperties);

   virtual bool              isSupported       (PSZCRO                 pszJobProperties);

   virtual PSZCRO            getDeviceID       ();

   virtual Enumeration      *getEnumeration    (bool                   fInDeviceSpecific);

#ifndef RETAIL
   void                      outputSelf        ();
#endif
   virtual std::string       toString          (std::ostringstream&    oss);
   friend std::ostream&      operator<<        (std::ostream&          os,
                                                const XMLDeviceMedia&  self);

private:
   xmlNodePtr node_d;
   PSZRO      pszDeviceID_d;
};

#endif

==> Omni-0.9.2.tar.gz: Omni/XMLDevice/XMLDeviceMedia.hpp <==
/*
 *   IBM Omni driver
 *   Copyright (c) International Business Machines Corp., 2000
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Lesser General Public License as published
 *   by the Free Software Foundation; either version 2.1 of the License, or
 *   (at your option) any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 *   the GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public License
 *   along with this library; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef _XMLDeviceMedia
#define _XMLDeviceMedia

#include <DeviceMedia.hpp>

#include <XMLDevice.hpp>

class XMLDeviceMedia : public DeviceMedia
{
public:
                             XMLDeviceMedia    (Device                *pDevice,
                                                PSZRO                  pszJobProperties,
                                                BinaryData            *data,
                                                int                    iColorAdjustRequired,
                                                int                    iAbsorption,
                                                XmlNodePtr             node);
   virtual                  ~XMLDeviceMedia    ();

   virtual DeviceMedia      *create            (Device                *pDevice,
                                                PSZRO                  pszJobProperties);
   static DeviceMedia       *createS           (Device                *pDevice,
                                                PSZRO                  pszJobProperties);

   virtual bool              isSupported       (PSZCRO                 pszJobProperties);

   virtual PSZCRO            getDeviceID       ();

   virtual Enumeration      *getEnumeration    (bool                   fInDeviceSpecific);

#ifndef RETAIL
   void                      outputSelf        ();
#endif
   virtual std::string       toString          (std::ostringstream&    oss);
   friend std::ostream&      operator<<        (std::ostream&          os,
                                                const XMLDeviceMedia&  self);

private:
   XmlNodePtr node_d;
   PSZRO      pszDeviceID_d;
};

#endif
